@@ -414,7 +414,7 @@ QStringList  pkgInterface::listInstalls(const QStringList &packs, bool install,
   
     // Skip non-blank lines (wanted text)
     while (i.hasPrevious()) {
-      if (!i.peekPrevious().isEmpty()) {
+      if (!i.peekPrevious().isEmpty() && !i.peekPrevious().contains(' ')) {
        i.previous();
      } else {
         break;
